summaryrefslogtreecommitdiffstats
path: root/mISDN.h
diff options
context:
space:
mode:
Diffstat (limited to 'mISDN.h')
-rw-r--r--mISDN.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/mISDN.h b/mISDN.h
index 2881341..b93ebb2 100644
--- a/mISDN.h
+++ b/mISDN.h
@@ -42,7 +42,8 @@ struct mISDNport {
int l2hold; /* set, if layer 2 must be hold/checked */
time_t l2establish; /* time until establishing after link failure */
int use; /* counts the number of port that uses this port */
- int ntmode; /* is TRUE if port is nt mode */
+ int ntmode; /* is TRUE if port is NT mode */
+ int tespecial; /* is TRUE if port uses special TE mode */
int pri; /* is TRUE if port is a primary rate interface */
int tones; /* TRUE if tones are sent outside connect state */
int earlyb; /* TRUE if tones are received outside connect state */
@@ -79,7 +80,7 @@ calls with no bchannel (call waiting, call on hold).
/* mISDN none-object functions */
int mISDN_initialize(void);
void mISDN_deinitialize(void);
-struct mISDNport *mISDNport_open(int port, char *portname, int ptp, int force_nt, int l2hold, struct interface *interface);
+struct mISDNport *mISDNport_open(int port, char *portname, int ptp, int force_nt, int te_special, int l2hold, struct interface *interface);
void mISDNport_close_all(void);
void mISDNport_close(struct mISDNport *mISDNport);
void mISDN_port_reorder(void);